@@ -2,14 +2,16 @@
 
 import argparse
 import importlib
+import json
 import warnings
 
+from bokeh import embed
 from bokeh.colors import RGB
 import bokeh.io as bkio
 from bokeh.layouts import gridplot
 from bokeh.plotting import Figure
 
-__version__ = "0.3.12"
+__version__ = "0.4.0"
 
 # we don't run a comprehensive test suite and mostly in notebooks,
 # so show warnings all the time.
@@ -90,6 +92,21 @@ def show(plot, background=None):
             child.border_fill_color = colours[1]
 
 
+def export_jsx(plot, fname):
+    """Export plot to a JSX (react) file.
+
+    :param plot: bokeh plot object.
+    :param fname: export filename.
+    """
+    with open(fname, "w") as fh:
+        head = "const plotJson = "
+        data = embed.json_item(plot)
+        fh.write(head)
+        fh.write(json.dumps(data))
+        fh.write("\n")
+        fh.write("export default plotJson")
+
+
 def grid(plots, ncol=4, display=True, **kwargs):
     """Show a grid of plots in a notebook.
 
